DESCRIPTION
This is a serializer engine that allows you to turn Perl data structures into Data::Dumper output and vice-versa.
Since version 2.2.0 of Dancer2, the Dumper serializer is no longer shipped as part of the core framework, but is available as its own CPAN distribution, Dancer2-Serializer-Dumper. Install this distribution if you want to use it, and add its dependencies to your application.
SECURITY
The deserialize method evaluates the content as Perl code, inside a Safe compartment. Safe is not a real security sandbox, so this serializer must never be used to deserialize untrusted input. Dancer2's Dancer2::Serializer::Mutable serializer therefore leaves the Dumper serializer disabled by default: if you really want to opt in to it, you must set enable_dumper in your Mutable serializer configuration, and you must have this distribution installed.
METHODS
Returns 'text/x-data-dumper'
This is an helper available to transform a Data::Dumper output to a Perl data structures.
This is an helper available to transform a Perl data structures to a Data::Dumper output.
Calling this function will not trigger the serialization's hooks.
Serializes a Perl data structure into a Dumper string.
Deserialize a Dumper string into a Perl data structure.
5 POD Errors
The following errors were encountered while parsing the POD:
- Around line 66:
Unknown directive: =attr
- Around line 70:
Unknown directive: =func
- Around line 75:
Unknown directive: =func
- Around line 82:
Unknown directive: =method
- Around line 86:
Unknown directive: =method